@@ -1,4 +1,5 @@
 import threading
+from time import sleep
 import Pyro4
 import sys
 from pyage.core import inject
@@ -16,5 +17,7 @@ if __name__ == '__main__':
     Pyro4.config.COMMTIMEOUT = 1
     while not workspace.stopped:
         workspace.step()
+        if sys.argv[2]:
+            sleep(int(sys.argv[2]))
     workspace.daemon.close()
 
